@@ -5,14 +5,20 @@
 
 package Date::Language::Dutch;
 
+use strict;
+use warnings;
 use Date::Language ();
-use vars qw(@ISA @DoW @DoWs @MoY @MoYs @AMPM @Dsuf %MoY %DoW $VERSION);
-@ISA = qw(Date::Language);
-$VERSION = "1.01";
+use base 'Date::Language';
+
+our $VERSION = '2.34_01'; # TRIAL VERSION: generated
+# ABSTRACT: Dutch localization for Date::Format
+
+our (@DoW, @DoWs, @MoY, @MoYs, @AMPM, @Dsuf, %MoY, %DoW);
 
 @MoY  = qw(januari februari maart april mei juni juli
            augustus september oktober november december);
 @MoYs = map(substr($_, 0, 3), @MoY);
+$MoYs[2] = 'mrt'; # mrt is more common (Frank Maas)
 @DoW  = map($_ . "dag", qw(zon maan dins woens donder vrij zater));
 @DoWs = map(substr($_, 0, 2), @DoW);
 
@@ -21,10 +27,7 @@ $VERSION = "1.01";
 @Dsuf = ('e') x 31;
 
 
-@MoY{@MoY}  = (0 .. scalar(@MoY));
-@MoY{@MoYs} = (0 .. scalar(@MoYs));
-@DoW{@DoW}  = (0 .. scalar(@DoW));
-@DoW{@DoWs} = (0 .. scalar(@DoWs));
+Date::Language::_build_lookups();
 
 # Formatting routines
 
@@ -37,3 +40,30 @@ sub format_p { $_[0]->[2] >= 12 ?  $AMPM[1] : $AMPM[0] }
 sub format_o { sprintf("%2de",$_[0]->[3]) }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Date::Language::Dutch - Dutch localization for Date::Format
+
+=head1 VERSION
+
+version 2.34_01
+
+=head1 AUTHOR
+
+Graham <gbarr@pobox.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2020 by Graham Barr.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
